# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from sib_api_v3_sdk.models.get_extended_contact_details_statistics_clicked import GetExtendedContactDetailsStatisticsClicked  # noqa: F401,E501
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_messages_sent import GetExtendedContactDetailsStatisticsMessagesSent  # noqa: F401,E501
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_opened import GetExtendedContactDetailsStatisticsOpened  # noqa: F401,E501
from sib_api_v3_sdk.models.get_extended_contact_details_statistics_unsubscriptions import GetExtendedContactDetailsStatisticsUnsubscriptions  # noqa: F401,E501


class GetExtendedContactDetailsStatistics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'messages_sent': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'hard_bounces': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'soft_bounces': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'complaints': 'list[GetExtendedContactDetailsStatisticsMessagesSent]',
        'unsubscriptions': 'GetExtendedContactDetailsStatisticsUnsubscriptions',
        'opened': 'list[GetExtendedContactDetailsStatisticsOpened]',
        'clicked': 'list[GetExtendedContactDetailsStatisticsClicked]',
        'transac_attributes': 'list[object]'
    }

    attribute_map = {
        'messages_sent': 'messagesSent',
        'hard_bounces': 'hardBounces',
        'soft_bounces': 'softBounces',
        'complaints': 'complaints',
        'unsubscriptions': 'unsubscriptions',
        'opened': 'opened',
        'clicked': 'clicked',
        'transac_attributes': 'transacAttributes'
    }

    def __init__(self, messages_sent=None, hard_bounces=None, soft_bounces=None, complaints=None, unsubscriptions=None, opened=None, clicked=None, transac_attributes=None):  # noqa: E501
        """GetExtendedContactDetailsStatistics - a model defined in Swagger"""  # noqa: E501

        self._messages_sent = None
        self._hard_bounces = None
        self._soft_bounces = None
        self._complaints = None
        self._unsubscriptions = None
        self._opened = None
        self._clicked = None
        self._transac_attributes = None
        self.discriminator = None

        if messages_sent is not None:
            self.messages_sent = messages_sent
        if hard_bounces is not None:
            self.hard_bounces = hard_bounces
        if soft_bounces is not None:
            self.soft_bounces = soft_bounces
        if complaints is not None:
            self.complaints = complaints
        if unsubscriptions is not None:
            self.unsubscriptions = unsubscriptions
        if opened is not None:
            self.opened = opened
        if clicked is not None:
            self.clicked = clicked
        if transac_attributes is not None:
            self.transac_attributes = transac_attributes

    @property
    def messages_sent(self):
        """Gets the messages_sent of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the sent campaign for the contact  # noqa: E501

        :return: The messages_sent of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._messages_sent

    @messages_sent.setter
    def messages_sent(self, messages_sent):
        """Sets the messages_sent of this GetExtendedContactDetailsStatistics.

        Listing of the sent campaign for the contact  # noqa: E501

        :param messages_sent: The messages_sent of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._messages_sent = messages_sent

    @property
    def hard_bounces(self):
        """Gets the hard_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the hardbounes generated by the contact  # noqa: E501

        :return: The hard_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._hard_bounces

    @hard_bounces.setter
    def hard_bounces(self, hard_bounces):
        """Sets the hard_bounces of this GetExtendedContactDetailsStatistics.

        Listing of the hardbounes generated by the contact  # noqa: E501

        :param hard_bounces: The hard_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._hard_bounces = hard_bounces

    @property
    def soft_bounces(self):
        """Gets the soft_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the softbounes generated by the contact  # noqa: E501

        :return: The soft_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._soft_bounces

    @soft_bounces.setter
    def soft_bounces(self, soft_bounces):
        """Sets the soft_bounces of this GetExtendedContactDetailsStatistics.

        Listing of the softbounes generated by the contact  # noqa: E501

        :param soft_bounces: The soft_bounces of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._soft_bounces = soft_bounces

    @property
    def complaints(self):
        """Gets the complaints of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the complaints generated by the contact  # noqa: E501

        :return: The complaints of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """
        return self._complaints

    @complaints.setter
    def complaints(self, complaints):
        """Sets the complaints of this GetExtendedContactDetailsStatistics.

        Listing of the complaints generated by the contact  # noqa: E501

        :param complaints: The complaints of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsMessagesSent]
        """

        self._complaints = complaints

    @property
    def unsubscriptions(self):
        """Gets the unsubscriptions of this GetExtendedContactDetailsStatistics.  # noqa: E501


        :return: The unsubscriptions of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: GetExtendedContactDetailsStatisticsUnsubscriptions
        """
        return self._unsubscriptions

    @unsubscriptions.setter
    def unsubscriptions(self, unsubscriptions):
        """Sets the unsubscriptions of this GetExtendedContactDetailsStatistics.


        :param unsubscriptions: The unsubscriptions of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: GetExtendedContactDetailsStatisticsUnsubscriptions
        """

        self._unsubscriptions = unsubscriptions

    @property
    def opened(self):
        """Gets the opened of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the openings generated by the contact  # noqa: E501

        :return: The opened of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsOpened]
        """
        return self._opened

    @opened.setter
    def opened(self, opened):
        """Sets the opened of this GetExtendedContactDetailsStatistics.

        Listing of the openings generated by the contact  # noqa: E501

        :param opened: The opened of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsOpened]
        """

        self._opened = opened

    @property
    def clicked(self):
        """Gets the clicked of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the clicks generated by the contact  # noqa: E501

        :return: The clicked of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[GetExtendedContactDetailsStatisticsClicked]
        """
        return self._clicked

    @clicked.setter
    def clicked(self, clicked):
        """Sets the clicked of this GetExtendedContactDetailsStatistics.

        Listing of the clicks generated by the contact  # noqa: E501

        :param clicked: The clicked of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[GetExtendedContactDetailsStatisticsClicked]
        """

        self._clicked = clicked

    @property
    def transac_attributes(self):
        """Gets the transac_attributes of this GetExtendedContactDetailsStatistics.  # noqa: E501

        Listing of the transactional attributes for the contact  # noqa: E501

        :return: The transac_attributes of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :rtype: list[object]
        """
        return self._transac_attributes

    @transac_attributes.setter
    def transac_attributes(self, transac_attributes):
        """Sets the transac_attributes of this GetExtendedContactDetailsStatistics.

        Listing of the transactional attributes for the contact  # noqa: E501

        :param transac_attributes: The transac_attributes of this GetExtendedContactDetailsStatistics.  # noqa: E501
        :type: list[object]
        """

        self._transac_attributes = transac_attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetExtendedContactDetailsStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SendReportEmail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subject': 'str',
        'to': 'list[str]',
        'content_type': 'str',
        'bcc': 'list[str]',
        'cc': 'list[str]',
        'body': 'str'
    }

    attribute_map = {
        'subject': 'subject',
        'to': 'to',
        'content_type': 'contentType',
        'bcc': 'bcc',
        'cc': 'cc',
        'body': 'body'
    }

    def __init__(self, subject=None, to=None, content_type='html', bcc=None, cc=None, body=None):  # noqa: E501
        """SendReportEmail - a model defined in Swagger"""  # noqa: E501

        self._subject = None
        self._to = None
        self._content_type = None
        self._bcc = None
        self._cc = None
        self._body = None
        self.discriminator = None

        self.subject = subject
        self.to = to
        if content_type is not None:
            self.content_type = content_type
        if bcc is not None:
            self.bcc = bcc
        if cc is not None:
            self.cc = cc
        self.body = body

    @property
    def subject(self):
        """Gets the subject of this SendReportEmail.  # noqa: E501

        Subject of the email message  # noqa: E501

        :return: The subject of this SendReportEmail.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this SendReportEmail.

        Subject of the email message  # noqa: E501

        :param subject: The subject of this SendReportEmail.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def to(self):
        """Gets the to of this SendReportEmail.  # noqa: E501

        Email addresses of the recipients  # noqa: E501

        :return: The to of this SendReportEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this SendReportEmail.

        Email addresses of the recipients  # noqa: E501

        :param to: The to of this SendReportEmail.  # noqa: E501
        :type: list[str]
        """
        if to is None:
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def content_type(self):
        """Gets the content_type of this SendReportEmail.  # noqa: E501

        Type of the message body  # noqa: E501

        :return: The content_type of this SendReportEmail.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this SendReportEmail.

        Type of the message body  # noqa: E501

        :param content_type: The content_type of this SendReportEmail.  # noqa: E501
        :type: str
        """
        allowed_values = ["text", "html"]  # noqa: E501
        if content_type not in allowed_values:
            raise ValueError(
                "Invalid value for `content_type` ({0}), must be one of {1}"  # noqa: E501
                .format(content_type, allowed_values)
            )

        self._content_type = content_type

    @property
    def bcc(self):
        """Gets the bcc of this SendReportEmail.  # noqa: E501

        Email addresses of the recipients in bcc  # noqa: E501

        :return: The bcc of this SendReportEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this SendReportEmail.

        Email addresses of the recipients in bcc  # noqa: E501

        :param bcc: The bcc of this SendReportEmail.  # noqa: E501
        :type: list[str]
        """

        self._bcc = bcc

    @property
    def cc(self):
        """Gets the cc of this SendReportEmail.  # noqa: E501

        Email addresses of the recipients in cc  # noqa: E501

        :return: The cc of this SendReportEmail.  # noqa: E501
        :rtype: list[str]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this SendReportEmail.

        Email addresses of the recipients in cc  # noqa: E501

        :param cc: The cc of this SendReportEmail.  # noqa: E501
        :type: list[str]
        """

        self._cc = cc

    @property
    def body(self):
        """Gets the body of this SendReportEmail.  # noqa: E501

        Body of the email message  # noqa: E501

        :return: The body of this SendReportEmail.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this SendReportEmail.

        Body of the email message  # noqa: E501

        :param body: The body of this SendReportEmail.  # noqa: E501
        :type: str
        """
        if body is None:
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendReportEmail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from sib_api_v3_sdk.api.account_api import AccountApi
from sib_api_v3_sdk.api.attributes_api import AttributesApi
from sib_api_v3_sdk.api.contacts_api import ContactsApi
from sib_api_v3_sdk.api.email_campaigns_api import EmailCampaignsApi
from sib_api_v3_sdk.api.folders_api import FoldersApi
from sib_api_v3_sdk.api.lists_api import ListsApi
from sib_api_v3_sdk.api.process_api import ProcessApi
from sib_api_v3_sdk.api.reseller_api import ResellerApi
from sib_api_v3_sdk.api.sms_campaigns_api import SMSCampaignsApi
from sib_api_v3_sdk.api.smtp_api import SMTPApi
from sib_api_v3_sdk.api.senders_api import SendersApi
from sib_api_v3_sdk.api.transactional_sms_api import TransactionalSMSApi
from sib_api_v3_sdk.api.webhooks_api import WebhooksApi



# coding: utf-8

"""
    SendinBlue API

    SendinBlue provide a RESTFul API that can be used with any languages. With this API, you will be able to :   - Manage your campaigns and get the statistics   - Manage your contacts   - Send transactional Emails and SMS   - and much more...  You can download our wrappers at https://github.com/orgs/sendinblue  **Possible responses**   | Code | Message |   | :-------------: | ------------- |   | 200  | OK. Successful Request  |   | 201  | OK. Successful Creation |   | 202  | OK. Request accepted |   | 204  | OK. Successful Update/Deletion  |   | 400  | Error. Bad Request  |   | 401  | Error. Authentication Needed  |   | 402  | Error. Not enough credit, plan upgrade needed  |   | 403  | Error. Permission denied  |   | 404  | Error. Object does not exist |   | 405  | Error. Method not allowed  |   # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: contact@sendinblue.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sib_api_v3_sdk.api_client import ApiClient


class EmailCampaignsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_email_campaign(self, email_campaigns, **kwargs):  # noqa: E501
        """Create an email campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_email_campaign(email_campaigns, async=True)
        >>> result = thread.get()

        :param async bool
        :param CreateEmailCampaign email_campaigns: Values to create a campaign (required)
        :return: CreateModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_email_campaign_with_http_info(email_campaigns, **kwargs)  # noqa: E501
        else:
            (data) = self.create_email_campaign_with_http_info(email_campaigns, **kwargs)  # noqa: E501
            return data

    def create_email_campaign_with_http_info(self, email_campaigns, **kwargs):  # noqa: E501
        """Create an email campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_email_campaign_with_http_info(email_campaigns, async=True)
        >>> result = thread.get()

        :param async bool
        :param CreateEmailCampaign email_campaigns: Values to create a campaign (required)
        :return: CreateModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email_campaigns']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_email_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email_campaigns' is set
        if ('email_campaigns' not in params or
                params['email_campaigns'] is None):
            raise ValueError("Missing the required parameter `email_campaigns` when calling `create_email_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_campaigns' in params:
            body_params = params['email_campaigns']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_email_campaign(self, campaign_id, **kwargs):  # noqa: E501
        """Delete an email campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_email_campaign(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: id of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_email_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_email_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def delete_email_campaign_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Delete an email campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_email_campaign_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: id of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_email_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `delete_email_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def email_export_recipients(self, campaign_id, **kwargs):  # noqa: E501
        """Export the recipients of a campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.email_export_recipients(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param EmailExportRecipients recipient_export: Values to send for a recipient export request
        :return: CreatedProcessId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.email_export_recipients_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.email_export_recipients_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def email_export_recipients_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Export the recipients of a campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.email_export_recipients_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param EmailExportRecipients recipient_export: Values to send for a recipient export request
        :return: CreatedProcessId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'recipient_export']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method email_export_recipients" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `email_export_recipients`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'recipient_export' in params:
            body_params = params['recipient_export']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}/exportRecipients', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreatedProcessId',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_campaign(self, campaign_id, **kwargs):  # noqa: E501
        """Get campaign informations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_email_campaign(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :return: GetEmailCampaign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_email_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_email_campaign_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def get_email_campaign_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Get campaign informations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_email_campaign_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :return: GetEmailCampaign
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `get_email_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEmailCampaign',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_campaigns(self, **kwargs):  # noqa: E501
        """Return all your created campaigns  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_email_campaigns(async=True)
        >>> result = thread.get()

        :param async bool
        :param str type: Filter on the type of the campaigns
        :param str status: Filter on the status of the campaign
        :param datetime start_date: Mandatory if endDate is used. Starting (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent email campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param datetime end_date: Mandatory if startDate is used. Ending (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent email campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param int limit: Number of documents per page
        :param int offset: Index of the first document in the page
        :return: GetEmailCampaigns
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_email_campaigns_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_email_campaigns_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_email_campaigns_with_http_info(self, **kwargs):  # noqa: E501
        """Return all your created campaigns  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_email_campaigns_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str type: Filter on the type of the campaigns
        :param str status: Filter on the status of the campaign
        :param datetime start_date: Mandatory if endDate is used. Starting (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent email campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param datetime end_date: Mandatory if startDate is used. Ending (urlencoded) UTC date-time (YYYY-MM-DDTHH:mm:ss.SSSZ) to filter the sent email campaigns. Prefer to pass your timezone in date-time format for accurate result ( only available if either 'status' not passed and if passed is set to 'sent' )
        :param int limit: Number of documents per page
        :param int offset: Index of the first document in the page
        :return: GetEmailCampaigns
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type', 'status', 'start_date', 'end_date', 'limit', 'offset']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_campaigns" % key
                )
            params[key] = val
        del params['kwargs']

        if 'limit' in params and params['limit'] > 1000:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_email_campaigns`, must be a value less than or equal to `1000`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEmailCampaigns',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_email_campaign_now(self, campaign_id, **kwargs):  # noqa: E501
        """Send an email campaign id of the campaign immediately  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.send_email_campaign_now(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.send_email_campaign_now_with_http_info(campaign_id, **kwargs)  # noqa: E501
        else:
            (data) = self.send_email_campaign_now_with_http_info(campaign_id, **kwargs)  # noqa: E501
            return data

    def send_email_campaign_now_with_http_info(self, campaign_id, **kwargs):  # noqa: E501
        """Send an email campaign id of the campaign immediately  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.send_email_campaign_now_with_http_info(campaign_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_email_campaign_now" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `send_email_campaign_now`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}/sendNow', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_report(self, campaign_id, send_report, **kwargs):  # noqa: E501
        """Send the report of a campaigns  # noqa: E501

        A PDF will be sent to the specified email addresses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.send_report(campaign_id, send_report, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param SendReport send_report: Values for send a report (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.send_report_with_http_info(campaign_id, send_report, **kwargs)  # noqa: E501
        else:
            (data) = self.send_report_with_http_info(campaign_id, send_report, **kwargs)  # noqa: E501
            return data

    def send_report_with_http_info(self, campaign_id, send_report, **kwargs):  # noqa: E501
        """Send the report of a campaigns  # noqa: E501

        A PDF will be sent to the specified email addresses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.send_report_with_http_info(campaign_id, send_report, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param SendReport send_report: Values for send a report (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'send_report']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `send_report`")  # noqa: E501
        # verify the required parameter 'send_report' is set
        if ('send_report' not in params or
                params['send_report'] is None):
            raise ValueError("Missing the required parameter `send_report` when calling `send_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_report' in params:
            body_params = params['send_report']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}/sendReport', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_test_email(self, campaign_id, email_to, **kwargs):  # noqa: E501
        """Send an email campaign to your test list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.send_test_email(campaign_id, email_to, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param SendTestEmail email_to: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.send_test_email_with_http_info(campaign_id, email_to, **kwargs)  # noqa: E501
        else:
            (data) = self.send_test_email_with_http_info(campaign_id, email_to, **kwargs)  # noqa: E501
            return data

    def send_test_email_with_http_info(self, campaign_id, email_to, **kwargs):  # noqa: E501
        """Send an email campaign to your test list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.send_test_email_with_http_info(campaign_id, email_to, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param SendTestEmail email_to: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'email_to']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_test_email" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `send_test_email`")  # noqa: E501
        # verify the required parameter 'email_to' is set
        if ('email_to' not in params or
                params['email_to'] is None):
            raise ValueError("Missing the required parameter `email_to` when calling `send_test_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_to' in params:
            body_params = params['email_to']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}/sendTest', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_campaign_status(self, campaign_id, status, **kwargs):  # noqa: E501
        """Update a campaign status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_campaign_status(campaign_id, status, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param UpdateCampaignStatus status: Status of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.update_campaign_status_with_http_info(campaign_id, status, **kwargs)  # noqa: E501
        else:
            (data) = self.update_campaign_status_with_http_info(campaign_id, status, **kwargs)  # noqa: E501
            return data

    def update_campaign_status_with_http_info(self, campaign_id, status, **kwargs):  # noqa: E501
        """Update a campaign status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_campaign_status_with_http_info(campaign_id, status, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param UpdateCampaignStatus status: Status of the campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'status']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_campaign_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `update_campaign_status`")  # noqa: E501
        # verify the required parameter 'status' is set
        if ('status' not in params or
                params['status'] is None):
            raise ValueError("Missing the required parameter `status` when calling `update_campaign_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'status' in params:
            body_params = params['status']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}/status', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_email_campaign(self, campaign_id, email_campaign, **kwargs):  # noqa: E501
        """Update a campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_email_campaign(campaign_id, email_campaign, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param UpdateEmailCampaign email_campaign: Values to update a campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.update_email_campaign_with_http_info(campaign_id, email_campaign, **kwargs)  # noqa: E501
        else:
            (data) = self.update_email_campaign_with_http_info(campaign_id, email_campaign, **kwargs)  # noqa: E501
            return data

    def update_email_campaign_with_http_info(self, campaign_id, email_campaign, **kwargs):  # noqa: E501
        """Update a campaign  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.update_email_campaign_with_http_info(campaign_id, email_campaign, async=True)
        >>> result = thread.get()

        :param async bool
        :param int campaign_id: Id of the campaign (required)
        :param UpdateEmailCampaign email_campaign: Values to update a campaign (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['campaign_id', 'email_campaign']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_email_campaign" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'campaign_id' is set
        if ('campaign_id' not in params or
                params['campaign_id'] is None):
            raise ValueError("Missing the required parameter `campaign_id` when calling `update_email_campaign`")  # noqa: E501
        # verify the required parameter 'email_campaign' is set
        if ('email_campaign' not in params or
                params['email_campaign'] is None):
            raise ValueError("Missing the required parameter `email_campaign` when calling `update_email_campaign`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'campaign_id' in params:
            path_params['campaignId'] = params['campaign_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'email_campaign' in params:
            body_params = params['email_campaign']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api-key', 'partner-key']  # noqa: E501

        return self.api_client.call_api(
            '/emailCampaigns/{campaignId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
